+++
title = "A concept of active mount for space applications"
author = ["Dehaeze Thomas"]
draft = false
+++

Tags
: [Active Damping]({{< relref "active_damping.md" >}})

Reference
: (<a href="#citeproc_bib_item_1">Souleille et al. 2018</a>)

Author(s)
: Souleille, A., Lampert, T., Lafarga, V., Hellegouarch, S., Rondineau, A., Rodrigues, Gonccalo, &amp; Collette, C.

Year
: 2018

This article discusses the use of Integral Force Feedback with amplified piezoelectric stack actuators.

> In the proposed configuration, it can also be noticed by the softening effect inherent to force control is limited by the metallic suspension.


## Single degree-of-freedom isolator {#single-degree-of-freedom-isolator}

[Figure 1](#figure--fig:souleille18-model-piezo) shows a picture of the amplified piezoelectric stack.
The piezoelectric actuator is divided into two parts: one is used as an actuator, and the other one is used as a force sensor.

<a id="figure--fig:souleille18-model-piezo"></a>

{{< figure src="/ox-hugo/souleille18_model_piezo.png" caption="<span class=\"figure-number\">Figure 1: </span>Picture of an APA100M from Cedrat Technologies. Simplified model of a one DoF payload mounted on such isolator" >}}

<div class="table-caption">
  <span class="table-number">Table 1:</span>
  Parameters used for the model of the APA 100M
</div>

|            | Value                  | Meaning                                                        |
|------------|------------------------|----------------------------------------------------------------|
| \\(m\\)    | \\(1\\,[kg]\\)         | Payload mass                                                   |
| \\(k\_e\\) | \\(4.8\\,[N/\mu m]\\)  | Stiffness used to adjust the pole of the isolator              |
| \\(k\_1\\) | \\(0.96\\,[N/\mu m]\\) | Stiffness of the metallic suspension when the stack is removed |
| \\(k\_a\\) | \\(65\\,[N/\mu m]\\)   | Stiffness of the actuator                                      |
| \\(c\_1\\) | \\(10\\,[N/(m/s)]\\)   | Added viscous damping                                          |

The dynamic equation of the system is:

\begin{equation}
  m \ddot{x}\_1 = \left( k\_1 + \frac{k\_ek\_a}{k\_e + k\_a} \right) ( w - x\_1) + c\_1 (\dot{w} - \dot{x}\_1) + F + \left( \frac{k\_e}{k\_e + k\_a} \right)f
\end{equation}

The expression of the force measured by the force sensor is:

\begin{equation}
  F\_s = \left( -\frac{k\_e k\_a}{k\_e + k\_a} \right) x\_1 + \left( \frac{k\_e k\_a}{k\_e + k\_a} \right) w + \left( \frac{k\_e}{k\_e + k\_a} \right) f
\end{equation}

and the control force is given by:

\begin{equation}
  f = F\_s G(s) = F\_s \frac{g}{s}
\end{equation}

The effect of the controller are shown in [Figure 2](#figure--fig:souleille18-tf-iff-result):

-   the resonance peak is almost critically damped
-   the passive isolation \\(\frac{x\_1}{w}\\) is not degraded at high frequencies
-   the degradation of the compliance \\(\frac{x\_1}{F}\\) induced by feedback is limited at \\(\frac{1}{k\_1}\\)
-   the fraction of the force transmitted to the payload that is measured by the force sensor is reduced at low frequencies

<a id="figure--fig:souleille18-tf-iff-result"></a>

{{< figure src="/ox-hugo/souleille18_tf_iff_result.png" caption="<span class=\"figure-number\">Figure 2: </span>Matrix of transfer functions from input (w, f, F) to output (Fs, x1) in open loop (blue curves) and closed loop (dashed red curves)" >}}

<a id="figure--fig:souleille18-root-locus"></a>

{{< figure src="/ox-hugo/souleille18_root_locus.png" caption="<span class=\"figure-number\">Figure 3: </span>Single DoF system. Comparison between the theoretical (solid curve) and the experimental (crosses) root-locus" >}}


## Flexible payload mounted on three isolators {#flexible-payload-mounted-on-three-isolators}

A heavy payload is mounted on a set of three isolators ([Figure 4](#figure--fig:souleille18-setup-flexible-payload)).
The payload consists of two  masses, connected through flexible blades such that the flexible resonance of the payload in the vertical direction is around 65Hz.

<a id="figure--fig:souleille18-setup-flexible-payload"></a>

{{< figure src="/ox-hugo/souleille18_setup_flexible_payload.png" caption="<span class=\"figure-number\">Figure 4: </span>Right: picture of the experimental setup. It consists of a flexible payload mounted on a set of three isolators. Left: simplified sketch of the setup, showing only the vertical direction" >}}

As shown in [Figure 5](#figure--fig:souleille18-result-damping-transmissibility), both the suspension modes and the flexible modes of the payload can be critically damped.

<a id="figure--fig:souleille18-result-damping-transmissibility"></a>

{{< figure src="/ox-hugo/souleille18_result_damping_transmissibility.png" caption="<span class=\"figure-number\">Figure 5: </span>Transmissibility between the table top \\(w\\) and \\(m\_1\\)" >}}


## Bibliography {#bibliography}

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
  <div class="csl-entry"><a id="citeproc_bib_item_1"></a>Souleille, Adrien, Thibault Lampert, V Lafarga, Sylvain Hellegouarch, Alan Rondineau, Gonçalo Rodrigues, and Christophe Collette. 2018. “A Concept of Active Mount for Space Applications.” <i>CEAS Space Journal</i> 10 (2). Springer: 157–65.</div>
</div>
