+++
title = "Robust mass damper design for bandwidth increase of motion stages"
author = ["Dehaeze Thomas"]
draft = true
+++

Tags
:


Reference
: (<a href="#citeproc_bib_item_1">Verbaan 2015</a>)

Author(s)
: Verbaan, C.

Year
: 2015

> This thesis addresses the challenge to increase the modal damping of the bandwidth limiting resonances of motions stages.
> This modal damping increase is realized by adding passive elements, called robust tuned mass dampers, at specific stage locations.
>
> [...]
>
> The damper parameters that have to be determined are mass, stiffness, and damping.
> The optimal parameters are obtained by executing optimization algorithm.
>
> The first motion stage design is optimized based on an open-loop criterion for modal damping increase between 1 and 4kHz.
> Experimental validation shows that a suppression factor of over 24dB is obtained.


## Robust Mass Damper and broad banded damping {#robust-mass-damper-and-broad-banded-damping}

> In high tech motion systems, the finite stiffness of mechanical components results in natural frequencies which limit the bandwidth of the control system.
> This is usually counteracted by increasing the controller complexity by adding notch filters.
> The height of the non-rigid body modes in the frequency response function and the amount of damping significantly affect the achievable bandwidth.
> This chapter described a method to add damping to the flexible behavior of a motion stage, by using robust mass dampers which are mass-spring-damper systems with an **over-critical** damping value.
> This high damping results in robust dynamic behavior with respect to stiffness and damping variations for both the motion stage and the damper mechanisms.
> The main result is a significant increase in modal damping over a broad band of resonance frequencies.


### Tuned mass damper {#tuned-mass-damper}

The effectiveness of the TMD is related to the mass ratio between \\(m\\) and \\(M\\).
To obtain a substantial suppression factor in combination with a relatively small increase in mass, the mass ratio is usually determined to be approximately 5 to 10% of the main structural mass.
The undamped natural frequency of the TMD has to be tuned close to the targeted natural frequency of the main structure.

A drawback of the TMD is the relatively **large sensitivity of the suppression factor for variations in stiffness and damping values**.
This sensitivity also holds for natural frequency variations of the main structure.

<a id="figure--fig:verbaan15-tmd-principle"></a>

{{< figure src="/ox-hugo/verbaan15_tmd_principle.png" caption="<span class=\"figure-number\">Figure 1: </span>TMD principle" >}}


### Damper design and validation {#damper-design-and-validation}

This damper is designed and tested to prove that it is possible to create dampers with over-critical damping values and with natural frequencies that are high enough to be useful.
The spring and damper are assumed to behave linearly.
In addition, the vibration amplitudes of high-tech positioning tables are small, which allows for assuming linear system theory.
These small vibration amplitudes lead to small damper strokes.
Therefore **flexures** can be used to provide for the guidance of the moving mass.
The dimensions of the flexures determine the spring stiffness and therefore the natural frequency of the TMD.
An additional advantage of flexures is the lack of hysteresis, which **enables the damper to work even if the damper strokes are very small**.

The dampers are intended to act purely in z-direction.
The natural frequency in this direction is determined at 1250Hz and the natural frequency in the other directions should be as high as possible.

<a id="figure--fig:verbaan15-tmd-modes"></a>

{{< figure src="/ox-hugo/verbaan15_tmd_modes.png" caption="<span class=\"figure-number\">Figure 2: </span>Natural frequency of the TMD. First natural frequency at 1250Hz and the second at 8100Hz." >}}

The second challenge is to create a damping mechanism with a high damping coefficient in a relatively small volume.
The damper is designed to be **passive**.
This guarantees stability of the damper system itself and preserves from increasing complexity.
As damping concept, a **viscous fuild damper** is chosen due to the following properties:

-   the linear time independent behavior
-   the ability to create an extremely large damping constant in a small volume
-   separation of stiffness and damping
-   the supreme damping properties of fuilds with respect to other damping materials

The guild applied is Rocol Kilopoise 0868 and is chosen based on the extremely high viscosity of 220 Pas.

In order to measure the damping the measurement bench shown in [3](#figure--fig:verbaan15-tmd-mech-system) is used.
The measured FRF are shown in [4](#figure--fig:verbaan15-obtained-damping-bench).
The measurement clearly shows that the damper mechanism is over-critically damped.

<a id="figure--fig:verbaan15-tmd-mech-system"></a>

{{< figure src="/ox-hugo/verbaan15_tmd_mech_system.png" caption="<span class=\"figure-number\">Figure 3: </span>Damper test setup to measure the damping characteristics" >}}

<a id="figure--fig:verbaan15-obtained-damping-bench"></a>

{{< figure src="/ox-hugo/verbaan15_obtained_damping_bench.png" caption="<span class=\"figure-number\">Figure 4: </span>Obtained damping results" >}}


## Linear viscoelastic characterisation of an ultra-high viscosity fluid {#linear-viscoelastic-characterisation-of-an-ultra-high-viscosity-fluid}

> This chapter presents the use of a state of the art damper for high precision motion stages as a sliding plate rheometer for measuring linear viscoelastic properties in the frequency range of 10Hz to 10kHz.
> This design is flexure based to minimize parasitic nonlinear forces.
> Design and the damping mechanism are elaborated and a model is presented that describes the dynamic behavior.

The damper shown in [5](#figure--fig:verbaan15-damper-parts) can be used as a sliding plate rheometer to measure the linear viscoelastic properties of ultra-high viscosity fluids in the frequency range 10Hz to 10kHz.

<a id="figure--fig:verbaan15-damper-parts"></a>

{{< figure src="/ox-hugo/verbaan15_damper_parts.png" caption="<span class=\"figure-number\">Figure 5: </span>Damper parts" >}}

The full damper assembly consists of a mass, mounted on two springs and a damper in parallel configuration.
The mass can make small strokes in the x-direction and is fixed in all other directions.
The spring is a double leaf spring guide.
The space between the lead springs is used to accommodate for the damping mechanism.

<a id="figure--fig:verbaan15-tmd-slot-fin-parts"></a>

{{< figure src="/ox-hugo/verbaan15_tmd_slot_fin_parts.png" caption="<span class=\"figure-number\">Figure 6: </span>Exploded view of the damper parts" >}}

A high-viscosity fluid is applied to create a velocity dependent force.
For this purpose, the sliding plate principle is used which induces a **shear flow**: the fluid is placed between two slot plates and a fin is positioned between these two plates ([7](#figure--fig:verbaan15single-double-fin)).
A **flexible encapsulation** is used to hold the fluid between find and slot part.

To study different damping values with the same fluid, two damper designs with different geometries are used (see [7](#figure--fig:verbaan15single-double-fin)).

<a id="figure--fig:verbaan15single-double-fin"></a>

{{< figure src="/ox-hugo/verbaan15single_double_fin.png" caption="<span class=\"figure-number\">Figure 7: </span>Cross-sectional views of the two different damping mechanims. The single fin (left) and double fin (right)." >}}

To excite the damper mass, a voice coil is mounted to the hardware.
The damper position is measured with a laser vibrometer.

A sliding plate damper for high frequencies introduces side effects:

1.  geometry related effects
2.  frequency dependent effects

A first geometrical effect is due to the **finite length of the plates**.
The ratio length/gap here is more than 100 which makes this effect negligible.
A second geometrical effect is due to the difficulty to get the **plates parallel to each other**, especially with the normal forces acting on the moving fin, induced by the flow.
This design counteracts this problem in two-ways: the damper part is **symmetric**, which means that the fin normal forces cancel each other.
In addition, the double leaf spring mechanism has a **very high lateral stiffness**, which minimizes lateral displacements.
A third geometrical effect is pumping of the fluid, which appears in the case of closed ends and introduces a flow opposite to the fin velocity, and therefore introduces a parasitic damping force.
This problem is avoided by letting the gaps' ends open.
The **fin is shorted than the slot** to maintain the same damping area over the damper stroke.

These effects all arise at low frequencies, at which the flow can be assumed homogeneous.
The ratio between inertial and viscous effects determines up to which frequency the flow can be assumed homogeneous:

\begin{equation}
t\_c = \frac{10 \rho h^2}{\eta}
\end{equation}

in which \\(\rho\\) describes the fluid density in \\(kg/m^3\\), \\(\eta\\) the dynamic viscosity in \\(Pa s\\) and \\(h\\) the gap width in \\(m\\).
Dimensions are provided in [1](#table--tab:single-fin-parameters).
This estimate results in a frequency above 100kHz.
It shows that high fluid viscosities and small gap widths enable high frequencies without losing homogeneous flow conditions.

<a id="table--tab:single-fin-parameters"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:single-fin-parameters">Table 1</a>:</span>
  Parameters for the single fin design
</div>

| Dimension      | Value [mm] |
|----------------|------------|
| Length \\(l\\) | 16         |
| Width \\(w\\)  | 8.5        |
| Gap \\(h\\)    | 0.12       |

**Conclusion**:
A design of a sliding plate damper that can be used to characterize fluid behavior of high viscosity fluids in the frequency range between 10Hz and 10kHz.
The drawbacks of standard sliding plate devices are taken care off by the mechanical design.
The flexure mechanism very precisely determines the position of the fin with respect to the slot part.
A three mode Maxwell model can accurately describe the behavior.


## Damping optimization of a complex motion stage {#damping-optimization-of-a-complex-motion-stage}


### Stage and damper dynamic models {#stage-and-damper-dynamic-models}

This chapter presents the results of a robust mass damper implementation on a complex motion stage with realistic natural frequencies to increase the modal damping of flexible modes.
A design approach is presented which results in parameter values for the dampers to improve the modal damping over a specified frequency range.

[8](#figure--fig:verbaan15-stage-undamped) shows a collocated FRF of the stage's corner.
The goal is to increase the modal damping of modes 7, 9, 10/11 and 13.

<a id="figure--fig:verbaan15-stage-undamped"></a>

{{< figure src="/ox-hugo/verbaan15_stage_undamped.png" caption="<span class=\"figure-number\">Figure 8: </span>FRF at the stage corner in the z-direction, undamped" >}}

The transfer function \\(T\_i(s)\\) is defined as the contribution of the a single mode \\(i\\) in an input/output transfer function:

\begin{equation}
T\_i(s) = \frac{\phi\_i^{\text{act}} \phi\_i^{\text{sen}}}{s^2 + 2 \xi \omega\_i s + \omega\_i^2} = \frac{1}{m\_i s^2 + c\_i s + k\_i}
\end{equation}

With \\(\phi\_i^{\text{act}}\\) and \\(\phi\_i^{\text{sen}}\\) the modal factors of the actuator and sensor.

From this equation, it appears that the modal mass of a mode in a certain transfer function equals:

\begin{equation}
m\_i = \frac{1}{\phi\_i^{\text{act}} \phi\_i^{\text{sen}}}
\end{equation}

This equation shows that a certain mode's modal mass depends on the locations of the actuator and sensor.
Since a TMD can be seen as a local control loop, the actuator and sensor location are equal.
This results in the following equation for the apparent modal mass for mode \\(i\\) at the TMD location:

\begin{equation}
m\_i = \frac{}{(\phi\_i^{\text{TMD}})^2}
\end{equation}

It is known from literature that the efficiency of a TMD depends on the **mass ratio** of the TMD and the mode that has to be damped.
It follows that the efficiency of a TMD to damp a certain resonance depends on the position of the damper on the stage in a quadratic sense.
The TMD has to be located at the maximum displacement of the mode(s) to be damped.

The damper configuration consists of an inertial mass \\(m\\), a transnational flexible guide designed as a double leaf spring mechanism with total stiffness \\(c\\) and a part that creates the damping force with damping constant \\(d\\) (model shown in [9](#figure--fig:verbaan15-maxwell-fluid-model)).
The velocity dependent damper force is the result of two parameters:

-   the fluid's mechanical properties
-   the damper geometry

The fluid model is presented in [10](#figure--fig:verbaan15-fluid-lve-model).
This figure shows the viscous and elastic properties of the fluid as a function of the frequency.
The damper principle is chosen to be a parallel plate damper based on the shear principle with the viscous fluid in between the two parallel plates.
In case of a velocity difference between these plates, a velocity gradient is created in the fluid causing a specific force per unit of area, which, multiplied by the effective area submerged in the fluid, leads to a damping force.

The damping can be expressed with a geometrical damping factor (GDF) in meters:

\begin{equation}
\text{GDF} = \frac{A}{h} = \frac{2 n l w}{h}
\end{equation}

with \\(A\\) the total area of the damper fins, \\(n\\) is the number of fins, \\(l\\) is the fin length, \\(w\\) is the fin width and \\(h\\) is the effective gap width in which the fluid is applied.

This GDF, combined with the fluid properties in Pas and Pa, lead to a spring stiffness in N/m and a damping constant in N/(m/s).

In general, larger suppression factors can be obtained with larger TMD masses.
In the example, the modal mass is 3.5kg and the damper mass is 110g (useful inertial mass of 65g).

<a id="figure--fig:verbaan15-maxwell-fluid-model"></a>

{{< figure src="/ox-hugo/verbaan15_maxwell_fluid_model.png" caption="<span class=\"figure-number\">Figure 9: </span>Damper model with multi-mode Maxwell fluid model included" >}}

<a id="figure--fig:verbaan15-fluid-lve-model"></a>

{{< figure src="/ox-hugo/verbaan15_fluid_lve_model.png" caption="<span class=\"figure-number\">Figure 10: </span>Storage and loss modulus of the 3 Maxwell mode LVE fluid model" >}}


### TMD and RMD optimisation {#tmd-and-rmd-optimisation}

An algorithm is used to optimize the damping and is used in two cases:

-   a small banded optimisation which includes a single resonance.
    This results in a **tuned mass damper** optimal design
-   a broad banded optimization which includes a range of resonances.
    This results in a **robust mass damper** optimal design

The algorithm is first used to calculate the optimal parameters to suppress a **single** resonance frequency.
The result is shown in [11](#figure--fig:verbaan15-tmd-optimization) and shows **Tuned Mass Damper** behavior.

For this single frequency, stiffness and damping values can be calculated by hand.

<a id="figure--fig:verbaan15-tmd-optimization"></a>

{{< figure src="/ox-hugo/verbaan15_tmd_optimization.png" caption="<span class=\"figure-number\">Figure 11: </span>Result of the optimization procedure. The cost function is specified between 1kHz and 2kHz. This implies that the first mode is suppressed by the damper." >}}

To obtain broad banded damping, the cost function is redefined between 1 and 4kHz.
[12](#figure--fig:verbaan15-broadbanded-damping-results) presents the resulting bode diagram.

<a id="figure--fig:verbaan15-broadbanded-damping-results"></a>

{{< figure src="/ox-hugo/verbaan15_broadbanded_damping_results.png" caption="<span class=\"figure-number\">Figure 12: </span>Result of the optimization procedure with the cost function specified between 1 and 4kHz. The result is a range of resonances that are suppressed by the dampers." >}}

Results of optimizations for increasing damper mass, in the range from 10 to 250g per damper are shown in [13](#figure--fig:verbaan15-results-fct-mass).

<a id="figure--fig:verbaan15-results-fct-mass"></a>

{{< figure src="/ox-hugo/verbaan15_results_fct_mass.png" caption="<span class=\"figure-number\">Figure 13: </span>Optimal damper parameters as a function of the damper mass. The upper graph shows the suppression factor in dB, the second graph shows the natural frequency of the damper in Hz and the lower graph shows the geometrical damping factor in m." >}}


### Damper Design and Validation {#damper-design-and-validation}

A damper mechanism is design which contains the following properties:

-   a moving mass \\(m\_d = 65\\,g\\)
-   a mounting mass \\(m\_m = 45\\,g\\)
-   a natural frequency \\(\omega\_0 = 1270\\,Hz\\)
-   other natural frequencies as high as possible
-   a geometrical damping factor of 14.3m
-   an encapsulation to contain the fluid

[14](#figure--fig:verbaan15-RMD-mechanical-parts) shows an exploded view of the RMD design.
The mechanism part is monolithically designed and consists of:

1.  a mounting side
2.  leaf spring pair
3.  the damper side

The fluid is surrounded by a flexible encapsulation, which prevents it from running out.

<a id="figure--fig:verbaan15-RMD-mechanical-parts"></a>

{{< figure src="/ox-hugo/verbaan15_RMD_mechanical_parts.png" caption="<span class=\"figure-number\">Figure 14: </span>Exploded view of the robust mass damper design with different parts indicated" >}}

<a id="figure--fig:verbaan15-RMD-design-modes"></a>

{{< figure src="/ox-hugo/verbaan15_RMD_design_modes.png" caption="<span class=\"figure-number\">Figure 15: </span>Four lowest natural frequencies and corresponding mode shapes of the RMD while mounted to a stage corner" >}}

<a id="figure--fig:verbaan15-tmd-side-front-views"></a>

{{< figure src="/ox-hugo/verbaan15_tmd_side_front_views.png" caption="<span class=\"figure-number\">Figure 16: </span>A side view and a front view of the fin and slot parts" >}}

| Dimension   | Value | Unit |
|-------------|-------|------|
| Length fin  | 17    | mm   |
| Height fins | 4     | mm   |
| Gap width   | 50    | um   |
| GDF         | 14    | m    |

<a id="figure--fig:verbaan15-damped-undamped-frf"></a>

{{< figure src="/ox-hugo/verbaan15_damped_undamped_frf.png" caption="<span class=\"figure-number\">Figure 17: </span>Measured undamped and damped FRF" >}}


### Conclusion {#conclusion}

This chapter shows an approach to add damping to a range of resonances of a motion stage by adding robust mass dampers.
Analysis is performed to calculate the damping increase beforehand, and experiments are conducted to validate the behavior of both the damper and the stage with dampers added.

The broadbanded solution shows a resonance suppression of at least 24.3dB between 1kHz and 4kHz.
The overall mass increase is less than 2%.

The robustness, as one of the most important properties of the RMD, is proven: the suppression factor is well predictable despite different errors and estimations:

-   stage model errors (the natural frequencies resulting from the FEM are an overestimation of the real frequencies)
-   fluid model errors
-   a simplified 1DoF model is applied as a damper model
-   production tolerances for the dampers

Tuned mass dampers are well known in literature.
The equations are proven to calculate the optimal suppression factor, natural frequency and damping ratio.
In these equations, the damper behavior is assumed to be purely viscous.
We shows that larger suppression factors are possible by using visco-elastic fluids as damping medium.
Although this effect is relatively small for single resonance suppression, it is larger for broadbanded suppression.
The damper benefits from the frequency dependent stiffness of the fluid.


## Conclusion {#conclusion}

In this thesis, the opportunities to increase the performance of high-tech motion systems are investigated by increasing the modal damping of non-rigid body resonances by introducing robust mass dampers (RMD), which provides damping over a broad frequency band.
A combination of techniques is applied to improve the performance of motion stages in a systematical way, including mechanical design, dynamic modeling, material characterization and optimization procedures.
Theoretical improvement factors are calculated and experimental validation is provided to support the theory.
The main conclusions of the previous chapters are summarized and listed by subject.


### Robust Mass Dampers {#robust-mass-dampers}

Robust mass dampers have proven to be able to provide **broad banded damping**.
In addition, **robust behavior** is proven in case of parameter variations of both the motion stage and/or the parameters of the RMDs.
This property explicitly underlines the suitability of RMDs to improve the behavior of motion stages that are operated in closed-loop conditions: parameter sensitive designs will result in a performance decrease and might eventually lead to destabilization of the closed-loop system.

The RMDs in this thesis are **passive and stand-alone devices**.
Advantages of these types of devices are

1.  the stabilizing behavior due to the principle of energy dissipation.
2.  The stand-alone property implies that no connection between any structural part and the motion stage is created, and no signal or power cables are needed which prevents the introduction of disturbance forces.
3.  The damper design by application of LVE behavior enables larger suppression factors than purely viscous fluid behavior.

At least in case of motion stages with a relatively large length-height ratio it appears that an overall mass contribution by the RMDs of 2 % of the stage mass is sufficient to improve the stage performance significantly.
This is proven by experiments.


### Influence on stage dynamics {#influence-on-stage-dynamics}

The relatively high modal damping of the RMDs prevents for visible effects in the rigid body mass line of the frequency response functions.
In other directions, the natural frequencies of the RMDs can be designed above 6 kHz for dampers of 65 g.
This is usually high enough to prevent for detrimental properties in the direction of motion


### RMD locations {#rmd-locations}

The **location of an RMD on the mechanical stage is a significant factor in the performance increase factor**.
The effectiveness of the RMD to improve the modal damping factor scales quadratically with the stage displacement at the damper location.
Therefore, if the limiting natural frequencies are determined, **the locations with large displacements for the corresponding mode shapes have to be found**.
In case of more than one resonance this might be a weighted criterion for the different modes.
This approach is applicable for both open- loop and closed-loop performance criteria.


### The fluid model {#the-fluid-model}

A **linear visco-elastic fluid model** is derived from measurements and applied in the optimization formulations.
The results show that the model quality is good enough to predict the system’s damped behavior quite accurately.


### Open-loop modal damping improvement {#open-loop-modal-damping-improvement}

The principle of **broad banded damping** is well applicable for practical cases: the intended damping range was 1-4 kHz.
In addition, a damping increase is visible up to 6 kHz.
This frequency range abundantly covers the range in which performance limiting flexibilities usually arise in motion stage designs.
An optimization criterion in terms of resonance suppression is applied and works well: this criterion inherently only optimizes the visible resonances at the actuator and sensor location.
The choice which resonances should be suppressed, therefore, is specified in the cost function by the frequency response function.
Robustness of the solution and broad banded effect in practical cases is proven by the experimental validation.
The calculated suppression factor compares well to the measured ones.
The suppression factor amounts approximately 24 dB between 1 and 4 kHz, which indicates a modal damping increase factor of 16.


### Closed-loop performance increase {#closed-loop-performance-increase}

The principle of closed-loop performance increase is formulated in an optimization formulation which accurately estimates the bandwidth improvement factor.
The optimization formulation is non-convex, however, a hybrid optimization procedure is able to solve this specific problem in a limited amount of time.
In addition to the improvements in the intended control loops, other control loops often benefit from the damping increase.


### Advantages in analysis {#advantages-in-analysis}

A more general observation regarding the analyses method is presented.
The approach with separate RMDs is an efficient approach which contains two large advantages: It enables to continue with the current applied mechanical design approach for high natural frequencies and increase the modal damping afterwards.
This enables to still apply the materials with high specific stiffness and low damping.

In the analysis phase the advantages are enormous:

1.  Undamped natural frequencies and mode shapes can be calculated and are valid for the low damped stage’s mechanical design.
    These algorithms are very efficient and large models can be solved.
2.  State space models can be created which contain the complexity of the FEM model and can be validated by calculating the responses by means of superposition of the undamped modes in the FEM software.
3.  RMDs can be added at specific locations.
    This results in non-proportional damping and complex mode shapes, which are correctly calculated by the state space model.
4.  This enables to apply optimization algorithms and compare different RMDs very quickly.

The complete model including dampers can be solved in FEM, however, this approach contains serious drawbacks:

1.  The mode shapes change from real normal modes to complex modes due to the damping at specific locations.
    This implies that complex solvers have to be applied.
    These solvers are much more time consuming than the solvers for real natural modes.
2.  The frequency response functions can be calculated using fully harmonic solvers.
    This results in the most accurate solution because the model is not truncated as in case of a state space model with a limited number of modes.
    However, this algorithm solves the complete model for every frequency point in the frequency response function and, therefore, this approach is extremely time-consuming.
3.  Therefore, in this approach the ability to implement different RMD parameters and execute optimization algorithms practically vanishes due to the limitations listed above.

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
  <div class="csl-entry"><a id="citeproc_bib_item_1"></a>Verbaan, C.A.M. 2015. “Robust mass damper design for bandwidth increase of motion stages.” Mechanical Engineering; Technische Universiteit Eindhoven.</div>
</div>
