+++
title = "Interferometers"
author = ["Dehaeze Thomas"]
draft = false
category = "equipment"
+++

Tags
: [Position Sensors]({{< relref "position_sensors.md" >}}), [Optics]({{< relref "optics.md" >}})


## Manufacturers {#manufacturers}

| Manufacturers                                                                                                | Country     |
|--------------------------------------------------------------------------------------------------------------|-------------|
| [Attocube](http://www.attocube.com/)                                                                         | Germany     |
| [Zygo](https://www.zygo.com/?/met/markets/stageposition/zmi/)                                                | USA         |
| [Smaract](https://www.smaract.com/interferometry)                                                            | Germany     |
| [Qutools](https://www.qutools.com/qudis/)                                                                    | Germany     |
| [Renishaw](https://www.renishaw.com/en/fibre-optic-laser-encoder-products--6594)                             | UK          |
| [Sios](https://sios-de.com/products/length-measurement/laser-interferometer/)                                | Germany     |
| [Keysight](https://www.keysight.com/en/pc-1000000393%3Aepsg%3Apgr/laser-heads?nid=-536900395.0&cc=FR&lc=fre) | USA         |
| [Optics11](https://optics11.com/)                                                                            | Netherlands |
| [Prodrive](https://prodrive-technologies.com/motion/products/interferometer/)                                | Netherlands |
| [Agito](https://agito-akribis.com/voice-coil-motors/)                                                        |             |


## Reviews {#reviews}

(<a href="#citeproc_bib_item_2">Ducourtieux 2018</a>, <a href="#citeproc_bib_item_2">2018</a>; <a href="#citeproc_bib_item_1">Bobroff 1993</a>, <a href="#citeproc_bib_item_1">1993</a>; <a href="#citeproc_bib_item_5">Thurner et al. 2015</a>, <a href="#citeproc_bib_item_5">2015</a>; <a href="#citeproc_bib_item_4">Loughridge and Abramovitch 2013</a>)


## Effect of Refractive Index - Environmental Units {#effect-of-refractive-index-environmental-units}

The measured distance is proportional to the refractive index of the air that depends on several quantities as shown in [Table 1](#table--tab:index-air) (Taken from (<a href="#citeproc_bib_item_5">Thurner et al. 2015</a>)).

<a id="table--tab:index-air"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:index-air">Table 1</a>:</span>
  Dependence of Refractive Index \(n\) of Air from Temperature \(T\), pressure \(p\), Humidity \(h\), and CO2 content \(x_c\). Taken around \(T = 20^oC\), \(p=101kPa\), \(h = 50\%\), \(x_c = 400 ppm\) and \(\lambda = 1530nm\)
</div>

| Physical Value                        | Refractive Index Sensitivity | Value                     |
|---------------------------------------|------------------------------|---------------------------|
| Temperature \\(T\\)                   | \\(dn/dT\ (K^{-1})\\)        | \\(-9.32\cdot 10^{-7}\\)  |
| Pressure \\(p\\)                      | \\(dn/dp\ (mbar^{-1})\\)     | \\(2.70\cdot 10^{-7}\\)   |
| Humidity \\(h\\)                      | \\(dn/dh\ (\text{%}^{-1})\\) | \\(-8.72\cdot 10^{-9}\\)  |
| \\(\text{CO}\_2\\) content \\(x\_c\\) | \\(dn/dx\_c\ (ppm^{-1})\\)   | \\(1.42\cdot 10^{-10}\\)  |
| Wavelength \\(\lambda\\)              | \\(dn/d\lambda\ (nm^{-1})\\) | \\(-8.59\cdot 10^{-10}\\) |

In order to limit the measurement uncertainty due to variation of air parameters, an Environmental Unit can be used that typically measures the temperature, pressure and humidity and compensation for the variation of refractive index in real time.

Typical characteristics of commercial environmental units are shown in [Table 2](#table--tab:environmental-units).

<a id="table--tab:environmental-units"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:environmental-units">Table 2</a>:</span>
  Characteristics of Environmental Units
</div>

|           | Temperature (\\(\pm\ ^oC\\)) | Pressure (\\(\pm\ hPa\\)) | Humidity \\(\pm\\\% RH\\) | Wavelength Accuracy (\\(\pm\ \text{ppm}\\)) |
|-----------|------------------------------|---------------------------|---------------------------|---------------------------------------------|
| Attocube  | 0.1                          | 1                         | 2                         | 0.5                                         |
| Renishaw  | 0.2                          | 1                         | 6                         | 1                                           |
| Picoscale | 0.2                          | 2                         | 2                         | 1                                           |


## Interferometer Precision {#interferometer-precision}

[Figure 1](#figure--fig:position-sensor-interferometer-precision) shows the expected precision as a function of the measured distance due to change of refractive index of the air (taken from (<a href="#citeproc_bib_item_3">Jang and Kim 2017</a>)).

<a id="figure--fig:position-sensor-interferometer-precision"></a>

{{< figure src="/ox-hugo/position_sensor_interferometer_precision.png" caption="<span class=\"figure-number\">Figure 1: </span>Expected precision of interferometer as a function of measured distance" >}}


## Sources of uncertainty {#sources-of-uncertainty}

Sources of error in laser interferometry are well described in (<a href="#citeproc_bib_item_2">Ducourtieux 2018</a>).

It includes:

-   Laser Source Stability
-   Variation of refractive index of air, which is dependent of:
    -   Temperature: \\(K\_T \approx 1 ppmK^{-1}\\)
    -   Pressure: \\(K\_P \approx 0.27 ppm hPa^{-1}\\)
    -   Humidity: \\(K\_{HR} \approx 0.01 ppm \\% RH^{-1}\\)
    -   These errors can partially be compensated using an environmental unit.
-   Air turbulence ([Figure 2](#figure--fig:interferometers-air-turbulence))
-   Non linearity

<a id="figure--fig:interferometers-air-turbulence"></a>

{{< figure src="/ox-hugo/interferometers_air_turbulence.png" caption="<span class=\"figure-number\">Figure 2: </span>Effect of air turbulences on measurement stability" >}}


## Bibliography {#bibliography}

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
  <div class="csl-entry"><a id="citeproc_bib_item_1"></a>Bobroff, N. 1993. “Recent Advances in Displacement Measuring Interferometry.” <i>Measurement Science and Technology</i> 4 (9): 907–26. doi:<a href="https://doi.org/10.1088/0957-0233/4/9/001">10.1088/0957-0233/4/9/001</a>.</div>
  <div class="csl-entry"><a id="citeproc_bib_item_2"></a>Ducourtieux, Sebastien. 2018. “Toward High Precision Position Control Using Laser Interferometry: Main Sources of Error.” doi:<a href="https://doi.org/10.13140/rg.2.2.21044.35205">10.13140/rg.2.2.21044.35205</a>.</div>
  <div class="csl-entry"><a id="citeproc_bib_item_3"></a>Jang, Yoon-Soo, and Seung-Woo Kim. 2017. “Compensation of the Refractive Index of Air in Laser Interferometer for Distance Measurement: A Review.” <i>International Journal of Precision Engineering and Manufacturing</i> 18 (12): 1881–90. doi:<a href="https://doi.org/10.1007/s12541-017-0217-y">10.1007/s12541-017-0217-y</a>.</div>
  <div class="csl-entry"><a id="citeproc_bib_item_4"></a>Loughridge, Russell, and Daniel Y. Abramovitch. 2013. “A Tutorial on Laser Interferometry for Precision Measurements.” In <i>2013 American Control Conference</i>. doi:<a href="https://doi.org/10.1109/acc.2013.6580402">10.1109/acc.2013.6580402</a>.</div>
  <div class="csl-entry"><a id="citeproc_bib_item_5"></a>Thurner, Klaus, Francesca Paola Quacquarelli, Pierre-François Braun, Claudio Dal Savio, and Khaled Karrai. 2015. “Fiber-Based Distance Sensing Interferometry.” <i>Applied Optics</i> 54 (10). Optical Society of America: 3051–63.</div>
</div>
