+++
title = "Isotropy of Parallel Manipulator"
author = ["Thomas Dehaeze"]
draft = false
+++

Tags
: [Stewart Platforms]({{<relref "stewart_platforms.md#" >}})

Here are some notes on the literature about the isotropy of parallel manipulators.


## ([Tsai and Huang 2003](#orgfdcbc5f)) {#tsai-and-huang-2003--orgfdcbc5f}


## ([Fassi, Legnani, and Tosi 2005](#org420bcfa)) {#fassi-legnani-and-tosi-2005--org420bcfa}


## ([Bandyopadhyay and Ghosal 2008](#org403a5a5)) {#bandyopadhyay-and-ghosal-2008--org403a5a5}

Uses `mathematica` to inverse analytical Jacobian matrix and obtain conditions for isotropy.


## ([Legnani et al. 2010](#orgf42f367)) {#legnani-et-al-dot-2010--orgf42f367}


### Abstract {#abstract}

A manipulator exhibits an _isotropic behaviour_ when it has the same performances along all the directions of the working space.

The authors introduce the new concept of _Point of Isotropy_, showing how in some circumstances a non-isotropic manipulator may be transform into an isotropic one simply changing the location of its Tool Center Point (TCP).


### Introduction {#introduction}

**Kinetostatic** of parallel manipulator can be studied with the following equations:

\begin{align}
  \dot{Q} &= J \dot{S} \\\\\\
  F\_s &= J^T F\_q \\\\\\
  J   &= \frac{\partial Q}{\partial S}
\end{align}

where \\(J\\) is the Jacobian matrix which relates the "gripper" velocity \\(\dot{S}\\) with those of the actuators \\(\dot{Q}\\), as well as the forces \\(F\_q\\) exerted by the actuators with the forces/torques \\(F\_s\\) applied to the gripper.


### Isotropy {#isotropy}

A robot is called **isotropic** if at least in one point of the working space some of its kinetostatic properties are homogeneous with respect to all the directions.

<div class="definition">
  <div></div>

-   **Velocity isotropy**: A manipulator is isotropic with respect to the velocity, if it can perform the same velocity along all the directions.
-   **Force isotropy**: A manipulator is isotropic with respect to the force, if it can exert the same force along all the directions.
-   **Stiffness isotropy**: A manipulator is isotropic with respect to the stiffness, if the deflection of the TCP produced by a force applied to it is always in the direction of the force and its magnitude is independent of the force direction.
-   **Mass isotropy**: A manipulator is isotropic with respect to the equivalent gripper mass, if the acceleration of the TCP produced by a force applied to it is always in the direction of the force and its magnitude is independent of the force direction.

</div>

A 6-DoF spatial manipulator is isotropic with respect to velocity if:

\begin{equation}
J^T J = \diag(j\_{xx}, j\_{yy}, j\_{zz}, j\_{\alpha\alpha}, j\_{\beta\beta}, j\_{\gamma\gamma}) \quad \text{with} \quad j\_{xx}=j\_{yy}=j\_{zz} \quad \text{and} \quad j\_{\alpha\alpha}=j\_{\beta\beta}=j\_{\gamma\gamma}
\end{equation}

The same condition holds for the force isotropy.

Assuming that the actuators are locked and that they are the only sources of compliance, the force \\(F\_s\\) to be applied to the end effector to produce a motion \\(dS\\) is:

\begin{equation}
F\_s = \underbrace{J^T K\_q J}\_{K\_s} dS \quad K\_q = \diag(\dots,k\_i,\dots)
\end{equation}

where \\(k\_i\\) is the stiffness of the ith actuator.
A general 6-DoF manipulator is **fully isotropic** with respect to stiffness if:

\begin{equation}
K\_s = \diag(k\_{xx}, k\_{yy}, k\_{zz}, k\_{\alpha\alpha}, k\_{\beta\beta}, k\_{\gamma\gamma}) \quad \text{with} \quad k\_{xx}=k\_{yy}=k\_{zz}=k\_x \quad \text{and} \quad k\_{\alpha\alpha}=k\_{\beta\beta}=k\_{\gamma\gamma}=k\_\phi
\end{equation}

In this case, it results:

\begin{equation}
F = k\_x dX, \quad T = k\_\phi d\phi
\end{equation}

where \\(k\_x\\) is the translation stiffness and \\(k\_\phi\\) is the rotation stiffness.
This means that:

-   forces \\(F\\) applied to the TCP do not produce rotations \\(d\phi\\) but only translations \\(dX\\)
-   the translation is proportional to the force and parallel to it regardless to the force direction
-   torques \\(T\\) applied to the TCP do not produce translations \\(dx\\) but only rotations \\(d\phi\\)
-   the rotation is proportional to the torque and occurs around the same axis as the applied torque

In this special case in which all the actuators are identical to each other, and therefore have the same stiffness \\(k\\), we have \\(K\_s = kJ^TJ\\) and the condition number of the matrix \\(J^TJ\\) can be investigated instead of that of \\(J^T K\_q J\\).
In this case the isotropy for velocity, force and stiffness are achieve simultaneously.

A manipulator is **partially isotropic** if:

\begin{equation}
k\_{xx} = k\_{yy} \neq k\_{zz} \quad \text{and/or} \quad k\_{\alpha\alpha} = k\_{\beta\beta} \neq k\_{\gamma\gamma}
\end{equation}


### Point of isotropy {#point-of-isotropy}

A parallel manipulator as a "point of isotropy" if it exists at least one point of its end effector for which the isotropy condition is achieved.

Then conditions are given to find an isotropic TCP.


### Application to the Stewart platform {#application-to-the-stewart-platform}

Conditions can be applied to the Stewart platform and isotropy points can be found.


## ([Tong et al. 2011](#org3d4f33e)) {#tong-et-al-dot-2011--org3d4f33e}

A parallel manipulator consists of a movable platform, a fixed base, and six struts, each with a linear actuator.
The struts are partitioned into two groups: the first group with strut 1,3,5 and the second group with strut 2,4,6.
The attached points of each strut are uniformly spaced on the circumferences of two circles on the movable platform and the fixed base, respectively.
The three struts in each group are rotational symmetry and repeat every 120 deg.
This parallel manipulator with this kind of configurations are defined as generalized symmetric Gough-Stewart parallel manipulators (GSGSPMs).

<a id="org1222642"></a>

{{< figure src="/ox-hugo/tong11_architecture_gsgspm.png" caption="Figure 1: Architecture of a GSGSPM" >}}

A compliance center exists consequentially for any GSGSPMs.
At the compliance center, a GSGSPM is uncoupled.


## ([Legnani et al. 2012](#orgac23b06)) {#legnani-et-al-dot-2012--orgac23b06}

A manipulator is called partially of totally decoupled if the general movements of the robot can be subdivided in elementary tasks, each actuated by one or a group of actuators.
Decoupling may be referred to the end effector coordinate or to local kinetostatic properties related to the Jacobian.

-   Total decoupling occurs when the Jacobian is diagonal
-   Partial decoupling is when the Jacobian is triangular
-   Block decoupling is when the Jacobian is block diagonal

<a id="orga046465"></a>

{{< figure src="/ox-hugo/legnani12_isotropic_pkm.png" caption="Figure 2: An isotropic PKM" >}}

<summary>
The paper discusses the concepts of isotropy and decoupling in n-DoF PKM.
The role of different Jacobian matrices in the isotropy, decoupling and in general mobility analysis of manipulators is recalled.
It is highlighted how isotropy and decoupling may be achieved for pure translational manipulators in the whole workspace while rotational manipulators maybe decoupling in only one configuration.
</summary>


## ([Ding et al. 2014](#orga0fa269)) {#ding-et-al-dot-2014--orga0fa269}


## ([Afzali-Far 2016](#orgc42aa83)) {#afzali-far-2016--orgc42aa83}

> The problem of dynamic isotropy, as an optimal design solution for hexapods, is also addressed in this dissertation.
> **Dynamic isotropy is a condition in which all eigenfrequencies of a robot are equal**.


## ([Wu et al. 2018](#orgbacd7c7)) {#wu-et-al-dot-2018--orgbacd7c7}

Isotropy => J\*J' = a\*I

-   Stiffness isotropy = static isotropy
-   velocity isotropy = kinematic isotropy

They also proved that the symmetric generalized Stewart platform at a neutral position could be fully decoupled by adjusting the payload's center of mass to coincide with its **compliance center**. ([Tong et al. 2011](#org3d4f33e))

Dynamic isotropy => same resonance frequency for all suspension modes.

<a id="orge4ddb31"></a>

{{< figure src="/ox-hugo/wu18_stewart_picture.png" caption="Figure 3: Optimized Stewart platform" >}}


## ([Yang et al. 2020](#orge144852)) {#yang-et-al-dot-2020--orge144852}

<summary>
This paper proposes a novel concept, namely _isotropic control_  to solve the problem of having identical performance in all DoF.
Dynamic equations of parallel mechanisms with base excitation are established and analyzed.
An isotropic control framework is then synthesized in modal space.
The multi-DoF system is transformed into multi identical single-DoF systems.
Under the framework of isotropic control, parallel mechanisms obtain an identical frequency response for all modes.
An identical corner frequency, active damping, and rate of low-frequency transmissibility are achieved for all modes.
</summary>


## ([Kang et al. 2020](#orgb043f30)) {#kang-et-al-dot-2020--orgb043f30}



## Bibliography {#bibliography}

<a id="orgc42aa83"></a>Afzali-Far, Behrouz. 2016. “Vibrations and Dynamic Isotropy in Hexapods-Analytical Studies.” Lund University.

<a id="org403a5a5"></a>Bandyopadhyay, Sandipan, and Ashitava Ghosal. 2008. “An Algebraic Formulation of Kinematic Isotropy and Design of Isotropic 6-6 Stewart Platform Manipulators.” _Mechanism and Machine Theory_ 43 (5):591–616. <https://doi.org/10.1016/j.mechmachtheory.2007.05.003>.

<a id="orga0fa269"></a>Ding, Boyin, Benjamin S. Cazzolato, Richard M. Stanley, Steven Grainger, and John J. Costi. 2014. “Stiffness Analysis and Control of a Stewart Platform-Based Manipulator with Decoupled Sensor-Actuator Locations for Ultrahigh Accuracy Positioning under Large External Loads.” _Journal of Dynamic Systems, Measurement, and Control_ 136 (6):nil. <https://doi.org/10.1115/1.4027945>.

<a id="org420bcfa"></a>Fassi, Irene, Giovanni Legnani, and Diego Tosi. 2005. “Geometrical Conditions for the Design of Partial or Full Isotropic Hexapods.” _Journal of Robotic Systems_ 22 (10):507–18. <https://doi.org/10.1002/rob.20074>.

<a id="orgb043f30"></a>Kang, Shengzheng, Hongtao Wu, Shengdong Yu, Yao Li, Xiaolong Yang, and Jiafeng Yao. 2020. “Modeling and Control of a Six-Axis Parallel Piezo-Flexural Micropositioning Stage with Cross-Coupling Hysteresis Nonlinearities.” In _2020 IEEE/ASME International Conference on Advanced Intelligent Mechatronics (AIM)_, 1350–55. IEEE.

<a id="orgac23b06"></a>Legnani, G., I. Fassi, H. Giberti, S. Cinquemani, and D. Tosi. 2012. “A New Isotropic and Decoupled 6-Dof Parallel Manipulator.” _Mechanism and Machine Theory_ 58 (nil):64–81. <https://doi.org/10.1016/j.mechmachtheory.2012.07.008>.

<a id="orgf42f367"></a>Legnani, Giovanni, D Tosi, I Fassi, Hermes Giberti, and Simone Cinquemani. 2010. “The ‘Point of Isotropy’ and Other Properties of Serial and Parallel Manipulators.” _Mechanism and Machine Theory_ 45 (10). Elsevier:1407–23.

<a id="org3d4f33e"></a>Tong, Zhizhong, Jingfeng He, Hongzhou Jiang, and Guangren Duan. 2011. “Optimal Design of a Class of Generalized Symmetric Gough-Stewart Parallel Manipulators with Dynamic Isotropy and Singularity-Free Workspace.” _Robotica_ 30 (2):305–14. <https://doi.org/10.1017/s0263574711000531>.

<a id="orgfdcbc5f"></a>Tsai, K.Y., and K.D. Huang. 2003. “The Design of Isotropic 6-Dof Parallel Manipulators Using Isotropy Generators.” _Mechanism and Machine Theory_ 38 (11):1199–1214. <https://doi.org/10.1016/s0094-114x(03)00067-3>.

<a id="orgbacd7c7"></a>Wu, Ying, Kaiping Yu, Jian Jiao, Dengqing Cao, Weichao Chi, and Jie Tang. 2018. “Dynamic Isotropy Design and Analysis of a Six-Dof Active Micro-Vibration Isolation Manipulator on Satellites.” _Robotics and Computer-Integrated Manufacturing_ 49 (nil):408–25. <https://doi.org/10.1016/j.rcim.2017.08.003>.

<a id="orge144852"></a>Yang, Xiaolong, Hongtao Wu, Yao Li, Shengzheng Kang, Bai Chen, Huimin Lu, Carman K. M. Lee, and Ping Ji. 2020. “Dynamics and Isotropic Control of Parallel Mechanisms for Vibration Isolation.” _IEEE/ASME Transactions on Mechatronics_ 25 (4):2027–34. <https://doi.org/10.1109/tmech.2020.2996641>.
