+++
title = "Quadrant Photodiodes"
author = ["Dehaeze Thomas"]
draft = false
category = "equipment"
+++

Tags
: [Position Sensors]({{< relref "position_sensors.md" >}}), [Optics]({{< relref "optics.md" >}})


## Working principle {#working-principle}

<a id="figure--fig:quadrant-photodiode-schematic"></a>

{{< figure src="/ox-hugo/quadrant_photodiode_schematic.png" caption="<span class=\"figure-number\">Figure 1: </span>Schematic of the Quadrant Photodiode" >}}

The \\([x,y]\\) position of the beam on the quadrant photodiode can be estimated using the following equations:

\begin{align}
\sigma\_x &= \frac{(I\_B + I\_D) - (I\_A + I\_C)}{I\_A + I\_B + I\_C + I\_D} = \frac{I\_B + I\_D}{I\_A + I\_B + I\_C + I\_D} - 1 \\\\
\sigma\_y &= \frac{(I\_A + I\_B) - (I\_C + I\_D)}{I\_A + I\_B + I\_C + I\_D} = \frac{I\_A + I\_B}{I\_A + I\_B + I\_C + I\_D} - 1
\end{align}

<a id="figure--fig:quadrant-photodiode-spot-size"></a>

{{< figure src="/ox-hugo/quadrant_photodiode_relation_meas.png" caption="<span class=\"figure-number\">Figure 2: </span>Relation between the X position of the spot and the estimated measurement \\(\sigma\_x\\)" >}}

This is true when the spot is near the center of the four quadrants (linear region).

<a id="figure--fig:quadrant-photodiode-spot-size"></a>

{{< figure src="/ox-hugo/quadrant_photodiode_spot_size.jpg" caption="<span class=\"figure-number\">Figure 3: </span>Effect of the spot size on the sensitibility and measurement range" >}}

Basic requirements (taken from [here](https://www.aptechnologies.co.uk/home/support/photodiodes)):

-   detector gap &lt; spot size &lt; detector size
-   positional range &lt; spot size
-   positional range is proportional to the spot size
-   positional resolution is inversely proportional to the spot size

Estimation of the linear region.

The relation between the spot size and the quadrant photodiode sensitivity is well explained in (<a href="#citeproc_bib_item_2">Lee et al. 2010</a>).

Usually, single mode laser are used such that the beam profile can well be approximated by a Gaussian distribution.
The irradiance distribution is then:

\begin{equation}
I( r) = \frac{P}{\pi w^2} e^{-\frac{r^2}{w^2}}
\end{equation}

with:

-   \\(r\\) the radius
-   \\(P\\) the overall light source optical power
-   \\(w\\) the light spot radius for which the irradiance drops to the \\(1/e\\) value of its central value


## Estimation of photodiode gain {#estimation-of-photodiode-gain}

It is function of:

-   the spot size
-   the gain size

Spot size of collimated bean at focal plane of a lens ([link](https://www.gentec-eo.com/blog/spot-size-of-laser-beam)).

See:

-   (<a href="#citeproc_bib_item_5">Ng, Tan, and Foo 2007</a>)
-   (<a href="#citeproc_bib_item_4">Manojlović 2011</a>)
-   (<a href="#citeproc_bib_item_6">Wu et al. 2015</a>)
-   (<a href="#citeproc_bib_item_1">Azaryan et al. 2019</a>)
-   (<a href="#citeproc_bib_item_3">Li et al. 2019</a>)


## Electrical Readout {#electrical-readout}

[Transimpedance Amplifiers]({{< relref "transimpedance_amplifiers.md" >}}) amplifiers are required (schematic shown in Figure [4](#figure--fig:quadrant-transresistance-amplifier)).

-   Trade-off between gain / noise / bandwidth (see [The art of electronics - third edition]({{< relref "horowitz15_art_of_elect_third_edition.md" >}}), chapter 8.11.4).

The amplifier in Figure [4](#figure--fig:quadrant-transresistance-amplifier) produces a voltage:

\begin{equation}
V\_{\text{out}} = -I\_{\text{sig}} R\_f
\end{equation}

So the gain of the amplifier is simply \\(-R\_f\\) in [V/A].

The feedback resistor creates a Johnson noise that corresponds to a current noise:

\begin{equation}
i\_{n} = \sqrt{4kT/R\_f} \quad [A/\sqrt{Hz}]
\end{equation}

This is usually larger than the amplifier input current noise.

<a id="figure--fig:quadrant-transresistance-amplifier"></a>

{{< figure src="/ox-hugo/quadrant_transresistance_amplifier.png" caption="<span class=\"figure-number\">Figure 4: </span>Transimpedance Amplifier; Current in, Voltage out" >}}


## Angle Measurement {#angle-measurement}


### Working Principle {#working-principle}

Combined with a lens, a quadrant photodiode can become an angular sensor is well located at the focal plane of the lens (see Figure [5](#figure--fig:quandrant-diode-angle-schematic)).

The relation between the position \\([y,z]\\) of the quadrant photodiode and the angle of the incident light \\([R\_y, R\_z]\\) is:

\begin{align}
y &=  f \cdot R\_z\\\\
z &= -f \cdot R\_y
\end{align}

<a id="figure--fig:quandrant-diode-angle-schematic"></a>

{{< figure src="/ox-hugo/quandrant_diode_angle_schematic.png" caption="<span class=\"figure-number\">Figure 5: </span>Optical schematic of combination of a quandrant photodiode with a lens" >}}


### Sensitivity of beam translation {#sensitivity-of-beam-translation}

The sensitivity to translation of the beam depends on how well the quadrant photodiode is located at the focal plane of the lens.
If we note \\(\Delta x\\) the distance between the focal plane and the quadrant plane, the sensitivity to a \\(\Delta z\\) motion of the beam is:

\begin{equation}
z = \Delta x \cdot \Delta z
\end{equation}

Therefore, the ratio \\(f/\Delta x\\) gives the ratio of the sensitivity to beam angle to the sensitivity of beam translation.

<div class="exampl">

Take a lens with focal of \\(f = 500\\,mm\\) and say the quadrant photodiode is positioned at the focal plane with an accuracy of \\(\Delta x = 1\\,mm\\):

\begin{equation}
\frac{f}{\Delta x} = 500
\end{equation}

This means that \\(1\\,mm\\) of vertical motion of the beam will give the same output than \\(500\\,mrad\\) of rotation of the beam.

</div>

<div class="exampl">

Say be want to determine with which precision the quadrant photodiode should be positioned.
We now that the maximum translation of the beam is \\(\Delta z = 1\\,mm\\) and this should have less effect than a beam rotation of \\(R\_y = 10\\,\mu rad\\), then the quadrant photodiode should be position with an accuracy \\(\Delta x\\) of:

\begin{equation}
\Delta x = f \frac{R\_y}{\Delta z} = 1\\,mm, \quad \text{with } f = 0.1\\,m
\end{equation}

</div>


## Bibliography {#bibliography}

## References

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
  <div class="csl-entry"><a id="citeproc_bib_item_1"></a>Azaryan, N. S., J. A. Budagov, M. V. Lyablin, A. A. Pluzhnikov, B. Di Girolamo, J.-Ch. Gayde, and D. Mergelkuhl. 2019. “Position-Sensitive Photoreceivers: Sensitivity and Detectable Range of Displacements of a Focused Single-Mode Laser Beam.” <i>Physics of Particles and Nuclei Letters</i> 16 (4): 354–76. doi:<a href="https://doi.org/10.1134/s1547477119040058">10.1134/s1547477119040058</a>.</div>
  <div class="csl-entry"><a id="citeproc_bib_item_2"></a>Lee, Eun Joong, Youngok Park, Chul Sung Kim, and Taejoon Kouh. 2010. “Detection Sensitivity of the Optical Beam Deflection Method Characterized with the Optical Spot Size on the Detector.” <i>Current Applied Physics</i> 10 (3): 834–37. doi:<a href="https://doi.org/10.1016/j.cap.2009.10.003">10.1016/j.cap.2009.10.003</a>.</div>
  <div class="csl-entry"><a id="citeproc_bib_item_3"></a>Li, Qing, Shaoxiong Xu, Jiawei Yu, Lingjie Yan, and Yongmei Huang. 2019. “An Improved Method for the Position Detection of a Quadrant Detector for Free Space Optical Communication.” <i>Sensors</i> 19 (1): 175. doi:<a href="https://doi.org/10.3390/s19010175">10.3390/s19010175</a>.</div>
  <div class="csl-entry"><a id="citeproc_bib_item_4"></a>Manojlović, Lazo M. 2011. “Quadrant Photodetector Sensitivity.” <i>Applied Optics</i> 50 (20). Optical Society of America: 3461–69.</div>
  <div class="csl-entry"><a id="citeproc_bib_item_5"></a>Ng, T.W., H.Y. Tan, and S.L. Foo. 2007. “Small Gaussian Laser Beam Diameter Measurement Using a Quadrant Photodiode.” <i>Optics &#38;Amp; Laser Technology</i> 39 (5): 1098–1100. doi:<a href="https://doi.org/10.1016/j.optlastec.2006.06.001">10.1016/j.optlastec.2006.06.001</a>.</div>
  <div class="csl-entry"><a id="citeproc_bib_item_6"></a>Wu, Jiabin, Yunshan Chen, Shijie Gao, Yimang Li, and Zhiyong Wu. 2015. “Improved Measurement Accuracy of Spot Position on an Ingaas Quadrant Detector.” <i>Applied Optics</i> 54 (27). Optical Society of America: 8049–54.</div>
</div>
