+++
title = "Voice Coil Actuators"
author = ["Dehaeze Thomas"]
draft = false
category = "equipment"
+++

Tags
: [Actuators]({{< relref "actuators.md" >}})


## Working Principle {#working-principle}


## Typical Specifications {#typical-specifications}


## Model of a Voice Coil Actuator {#model-of-a-voice-coil-actuator}

(<a href="#citeproc_bib_item_1">Schmidt, Schitter, and Rankers 2014</a>)


## Driving Electronics {#driving-electronics}

As the force is proportional to the current, a [Transconductance Amplifiers]({{< relref "transconductance_amplifiers.md" >}}) (voltage-controller current source) is generally used as the driving electronics.


## Manufacturers {#manufacturers}

| Manufacturers                                                                                                                       | Country                                                                                                                                                  |
|-------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------|
| [Akribis](https://akribis-sys.com/products/voice-coil-motors/avm-series)                                                            | Singapore (european distributors: [Maccon](https://www.maccon.de/en.html), [TDS PP](https://www.tds-pp.com/en/product/linear-voice-coil-actuators-avm/)) |
| [Thorlabs](https://www.thorlabs.com/newgrouppage9.cfm?objectgroup_id=14116)                                                         |                                                                                                                                                          |
| [Geeplus](https://www.geeplus.com/)                                                                                                 | UK                                                                                                                                                       |
| [PBA Systems](https://www.pbasystems.com.sg/product/circular-voice-coil-motor-cvc/)                                                 | Singapore                                                                                                                                                |
| [Magnetic Innovations](https://www.magneticinnovations.com/)                                                                        | Netherlands                                                                                                                                              |
| [H2tech](https://www.h2wtech.com/)                                                                                                  | USA                                                                                                                                                      |
| [Beikimco](http://www.beikimco.com/)                                                                                                | USA                                                                                                                                                      |
| [Monticont](http://www.moticont.com/)                                                                                               | USA                                                                                                                                                      |
| [Celera](https://www.celeramotion.com/applimotion/products/direct-drive-frameless-linear-motors/voice-coil/juke-series-round-body/) |                                                                                                                                                          |


## Voice Coil Stages {#voice-coil-stages}

| Manufacturers                                                                                       | Country     |
|-----------------------------------------------------------------------------------------------------|-------------|
| [TDS PP](https://www.tds-pp.com/en/product/voice-coil-actuator-stages/)                             | Switzerland |
| [Thorlabs](https://www.thorlabs.com/newgrouppage9.cfm?objectgroup_ID=14930)                         | USA         |
| [H2tech](https://www.h2wtech.com/category/voice-coil-stages#productInfo1)                           | USA         |
| [PBA](https://www.pbasystems.com.sg/product/circular-voice-coil-motor-cvca/)                        |             |
| [Monticont](http://www.pwr-con.com/ecommerce/default.asp?cat=Linear+Motor+Driven+Positioning+Stage) |             |


## Voice Coil for Vertical payload {#voice-coil-for-vertical-payload}

Let's consider a spring-mass system with a force actuator ([Figure 1](#figure--fig:voice-coil-vertical-mass-spring)).
Parameters are:

-   `m`: the mass payload in [kg]
-   `k`: the spring constant in [N/m]
-   `Fmax`: the maximum force applied by the voice coil in [N]

<a id="figure--fig:voice-coil-vertical-mass-spring"></a>

{{< figure src="/ox-hugo/voice_coil_vertical_mass_spring.png" caption="<span class=\"figure-number\">Figure 1: </span>Mass Spring System" >}}

`Dg`: deflection due to gravity in [m]
`Df`: maximum stroke using the voice coil in [m]
`f0`: the resonance frequency of spring-mass system in [Hz]

\begin{equation}
2 \pi f\_0 = \sqrt{\frac{k}{m}}
\end{equation}

\begin{equation}
D\_g = \frac{m g}{k}
\end{equation}

\begin{equation}
D\_f = \frac{F\_\max}{k}
\end{equation}


### Determine the required voice coil force as a function of the payload's resonance {#determine-the-required-voice-coil-force-as-a-function-of-the-payload-s-resonance}

Let's fix `m` (payload mass) and `Df` (wanted motion induced by the voice coil).
Then, let's vary `f0` and compute the corresponding `Dg`, `Fmax` and `k`.

```matlab
%% Fixed Parameters
g = 9.8; % [m/s^2]
m = 5; % [kg]
Df = 5e-3; % [m]

%% Suspension resonance is varied
f0 = 0.1:0.1:20; % [Hz]
```

```matlab
%% Other parameters are computed
k = m * (2*pi*f0).^2; % [N/m]
Dg = m * g ./ k; % [m]
Fmax = k * Df; % [N]
```

<a id="figure--fig:voice-coil-force-fct-f0"></a>

{{< figure src="/ox-hugo/voice_coil_force_fct_f0.png" caption="<span class=\"figure-number\">Figure 2: </span>Required Voice Coil Force as a function of the paylaod resonance and corresponding deflection due to gravity (mass is 5kg, stroke is 5mm)" >}}


### Determine the payload resonance as a function of the wanted stroke {#determine-the-payload-resonance-as-a-function-of-the-wanted-stroke}

Let's fix `m` (payload mass) and `Fmax` (maximum force applied by the Voice coil).
Then, let's vary `Df` and compute the corresponding `Dg`, `f0` and `k`.

```matlab
%% Fixed Parameters
g = 9.8; % [m/s^2]
m = 5; % [kg]
Fmax = 50; % [N]

%% Wanted stroke is varied
Df = 1e-3:1e-4:10e-3; % [m]
```

```matlab
%% Other parameters are computed
k = Fmax./Df; % [N/m]
f0 = sqrt(k/m)/2/pi; % [Hz]
Dg = m * g ./ k; % [m]
```

<a id="figure--fig:voice-coil-resonance-fct-stroke"></a>

{{< figure src="/ox-hugo/voice_coil_resonance_fct_stroke.png" caption="<span class=\"figure-number\">Figure 3: </span>Resonance frequency and deflection due to gravity as a function of the wanted stroke (Max voice coil force is 50N and payload mass is 5kg)" >}}

<a id="figure--fig:voice-coil-stiffness-fct-stroke"></a>

{{< figure src="/ox-hugo/voice_coil_stiffness_fct_stroke.png" caption="<span class=\"figure-number\">Figure 4: </span>Resonance frequency and deflection due to gravity as a function of the wanted stroke (Max voice coil force is 50N and payload mass is 5kg)" >}}


## Bibliography {#bibliography}

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
  <div class="csl-entry"><a id="citeproc_bib_item_1"></a>Schmidt, R Munnig, Georg Schitter, and Adrian Rankers. 2014. <i>The Design of High Performance Mechatronics - 2nd Revised Edition</i>. Ios Press.</div>
</div>
